==> haskell-hourglass-0.2.12-246-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hourglass.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hourglass
version:              0.2.12
visibility:           public
id:                   hourglass-0.2.12-IgEtyVcSREg9suG8D80qmq
key:                  hourglass-0.2.12-IgEtyVcSREg9suG8D80qmq
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-hourglass
synopsis:             simple performant time related library
description:
    Simple time library focusing on simple but powerful and performant API

    The backbone of the library are the Timeable and Time type classes.

    Each Timeable instances can be converted to type that has a Time instances,
    and thus are different representations of current time.

category:             Time
abi:                  fee84c1728600a213506aa936392f495
exposed:              True
exposed-modules:
    Data.Hourglass Data.Hourglass.Compat Data.Hourglass.Epoch
    Data.Hourglass.Types System.Hourglass Time.Compat Time.System
    Time.Types

hidden-modules:
    Data.Hourglass.Time Data.Hourglass.Format Data.Hourglass.Diff
    Data.Hourglass.Local Data.Hourglass.Calendar Data.Hourglass.Zone
    Data.Hourglass.Internal Data.Hourglass.Utils
    Data.Hourglass.Internal.Unix

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hourglass-0.2.12
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hourglass-0.2.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hourglass
hs-libraries:         HShourglass-0.2.12-IgEtyVcSREg9suG8D80qmq
depends:              base-4.16.4.0 deepseq-1.4.6.1
haddock-interfaces:   /usr/share/doc/haskell-hourglass/html/hourglass.haddock
haddock-html:         /usr/share/doc/haskell-hourglass/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hourglass-0.2.12-248-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hourglass.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hourglass
version:              0.2.12
visibility:           public
id:                   hourglass-0.2.12-AqgCZcM6ZmxAi8T3YvbuVc
key:                  hourglass-0.2.12-AqgCZcM6ZmxAi8T3YvbuVc
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-hourglass
synopsis:             simple performant time related library
description:
    Simple time library focusing on simple but powerful and performant API

    The backbone of the library are the Timeable and Time type classes.

    Each Timeable instances can be converted to type that has a Time instances,
    and thus are different representations of current time.

category:             Time
abi:                  4be005866ea236b933eb8f42621d6bc2
exposed:              True
exposed-modules:
    Data.Hourglass Data.Hourglass.Compat Data.Hourglass.Epoch
    Data.Hourglass.Types System.Hourglass Time.Compat Time.System
    Time.Types

hidden-modules:
    Data.Hourglass.Time Data.Hourglass.Format Data.Hourglass.Diff
    Data.Hourglass.Local Data.Hourglass.Calendar Data.Hourglass.Zone
    Data.Hourglass.Internal Data.Hourglass.Utils
    Data.Hourglass.Internal.Unix

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hourglass-0.2.12
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hourglass-0.2.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hourglass
hs-libraries:         HShourglass-0.2.12-AqgCZcM6ZmxAi8T3YvbuVc
depends:              base-4.16.4.0 deepseq-1.4.6.1
haddock-interfaces:   /usr/share/doc/haskell-hourglass/html/hourglass.haddock
haddock-html:         /usr/share/doc/haskell-hourglass/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
